;; Generated package description from with-editor.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "with-editor" "3.5.2.0.20260730.9" "Use the Emacsclient as $EDITOR" '((emacs "28.1") (compat "31.0") (cond-let "1.1") (llama "1.0")) :commit "2671aa47e610cbb2763858507d881bdb90b1065a" :authors '(("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev") :keywords '("processes" "terminals") :url "https://github.com/magit/with-editor")
